<?php
/*
Plugin Name:  301-302 Yönlendirme
Plugin URI: https://www.seogle.com.tr/wordpress-eklentilerimiz/
Description: İçeriklerinizi 301 yada 302 yönlendirme konusunda yardımcı olur.
Version: 1.0
Author: Okan CERİT
Author URI: https://www.linkedin.com/in/okancerit/
License: GPL2
*/

// Özel alanları içeriğin altına ekle
function custom_redirect_meta_box() {
    add_meta_box(
        'custom_redirect_meta_box',
        __('301-302  Yönlendirme', 'custom_redirect'),
        'display_custom_redirect_meta_box',
        'post',
        'normal',
        'high'
    );
}
add_action('add_meta_boxes', 'custom_redirect_meta_box');

// Özel alanları görüntüle
function display_custom_redirect_meta_box($post) {
    $redirect_type = get_post_meta($post->ID, '_redirect_type', true);
    $redirect_url = get_post_meta($post->ID, '_redirect_url', true);
    ?>
    <p>
        <label for="redirect_type"><?php _e('Yönlendirme Türü:', 'custom_redirect'); ?></label>
        <select name="redirect_type" id="redirect_type">
            <option value="normal" <?php selected($redirect_type, 'normal'); ?>><?php _e('Normal (varsayılan)', 'custom_redirect'); ?></option>
            <option value="301" <?php selected($redirect_type, '301'); ?>><?php _e('301 Kalıcı Yönlendirme', 'custom_redirect'); ?></option>
            <option value="302" <?php selected($redirect_type, '302'); ?>><?php _e('302 Geçici Yönlendirme', 'custom_redirect'); ?></option>
        </select>
    </p>
    <p>
        <label for="redirect_url"><?php _e('Yönlendirme URL\'si:', 'custom_redirect'); ?></label>
        <input type="text" name="redirect_url" id="redirect_url" value="<?php echo esc_url($redirect_url); ?>">
        <?php
        if (($redirect_type == '301' || $redirect_type == '302') && empty($redirect_url)) {
            echo '<span style="color:red;">' . __('Lütfen yönlendirilecek URL\'yi girin.', 'custom_redirect') . '</span>';
        }
        ?>
    </p>
    <?php
}

// Özel alan değerlerini kaydet
function save_custom_redirect_meta_box($post_id) {
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return;
    if (!current_user_can('edit_post', $post_id)) return;

    if (isset($_POST['redirect_type'])) {
        update_post_meta($post_id, '_redirect_type', sanitize_text_field($_POST['redirect_type']));
    }

    if (isset($_POST['redirect_url'])) {
        update_post_meta($post_id, '_redirect_url', esc_url_raw($_POST['redirect_url']));
    }
}
add_action('save_post', 'save_custom_redirect_meta_box');

// İçeriği yönlendir
function custom_redirect_content() {
    if (is_singular('post')) {
        global $post;
        $redirect_type = get_post_meta($post->ID, '_redirect_type', true);
        $redirect_url = get_post_meta($post->ID, '_redirect_url', true);

        if ($redirect_type && $redirect_type !== 'normal' && $redirect_url) {
            $redirect_code = $redirect_type == '301' ? 301 : 302;
            wp_redirect($redirect_url, $redirect_code);
            exit;
        }
    }
}
add_action('template_redirect', 'custom_redirect_content');

// Yönlendirme türü sütununu ekleyin
function custom_redirect_columns($columns) {
    $columns['redirect_type'] = __('Yönlendirme Türü', 'custom_redirect');
    return $columns;
}
add_filter('manage_posts_columns', 'custom_redirect_columns');

// Yönlendirme türü değerlerini gösterin
function custom_redirect_column_content($column_name, $post_id) {
    if ($column_name == 'redirect_type') {
        $redirect_type = get_post_meta($post_id, '_redirect_type', true);
        if ($redirect_type && $redirect_type !== 'normal') {
            echo $redirect_type == '301' ? '301 - Kalıcı' : '302 - Geçici';
        } else {
            // Varsayılan seçildiğinde sütuna hiçbir şey ekleme
            echo '-';
        }
    }
}
add_action('manage_posts_custom_column', 'custom_redirect_column_content', 10, 2);



